![CI](https://github.com/artdgn/lightfm-pandas/workflows/CI/badge.svg) ![PyPI](https://img.shields.io/pypi/v/lightfm-pandas?color=blue)

# LightFM-pandas
This is a reduced version of the [ml-recsys-tool](https://github.com/artdgn/ml-recsys-tools) 
that's focused on just tools for LightFM package.

